@@ -1,5 +1,5 @@
 package DBIx::Class::DeploymentHandler::VersionHandler::ExplicitVersions;
-$DBIx::Class::DeploymentHandler::VersionHandler::ExplicitVersions::VERSION = '0.002218';
+$DBIx::Class::DeploymentHandler::VersionHandler::ExplicitVersions::VERSION = '0.002233';
 use Moose;
 
 # ABSTRACT: Define your own list of versions to use for migrations
@@ -9,12 +9,11 @@ use Carp 'croak';
 with 'DBIx::Class::DeploymentHandler::HandlesVersioning';
 
 has schema_version => (
-  isa      => 'Str',
   is       => 'ro',
   required => 1,
 );
 
-has database_version => (
+has initial_version => (
   isa      => 'Str',
   is       => 'ro',
   required => 1,
@@ -55,11 +54,21 @@ has _version_idx => (
   lazy_build => 1,
 );
 
-sub _build__version_idx { $_[0]->_index_of_versions->{$_[0]->database_version} }
+sub _build__version_idx { $_[0]->_index_of_versions->{$_[0]->initial_version} }
 
 sub _inc_version_idx { $_[0]->_version_idx($_[0]->_version_idx + 1 ) }
 sub _dec_version_idx { $_[0]->_version_idx($_[0]->_version_idx - 1 ) }
 
+# provide backwards compatibility for initial_version/database_version
+around BUILDARGS => sub {
+    my $orig  = shift;
+    my $class = shift;
+
+    my $args = $class->$orig(@_);
+    $args->{initial_version} = $args->{database_version}
+      if exists $args->{database_version} && !exists $args->{initial_version};
+    return $args;
+};
 
 sub next_version_set {
   my $self = shift;
@@ -127,7 +136,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2019 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
